package de.fitko.fitconnect.api.services.validation;

import com.nimbusds.jose.jwk.RSAKey;
import de.fitko.fitconnect.api.domain.validation.ValidationResult;

/**
 * Validator for publicKeys and certificate chains.
 *
 * @see <a href="https://docs.fitko.de/fit-connect/docs/sending/encrypt/#certificateValidation">Certificate Validation</a>
 */
public interface CertificateValidator {

    /**
     *
     * Validates the public key consisting of the following steps:
     * <p>
     *     <ul>
     *     <li>checks if the JSON Web Key is suitable for the encryption</li>
     *     <li>checks if the public key is matching the certificate referenced in the</li>
     *     <li>checks the certificate chain up to the root certificate</li>
     *     <li>checks against a certificate revocation list and/or an OSCP-endpoint with signed response</li>
     * </ul>
     * @param publicKey the public encryption key that is validated
     *
     * @return {@link ValidationResult} that includes errors if the validation failed
     */
    ValidationResult validatePublicKey(final RSAKey publicKey);
}
